==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/auth/XSSOManager.hpp <==
#ifndef _COM_SUN_STAR_AUTH_XSSOMANAGER_HPP_
#define _COM_SUN_STAR_AUTH_XSSOMANAGER_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AUTH_XSSOMANAGER_HDL_
#include "com/sun/star/auth/XSSOManager.hdl"
#endif

#ifndef _COM_SUN_STAR_AUTH_XSSOACCEPTORCONTEXT_HPP_
#include "com/sun/star/auth/XSSOAcceptorContext.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_INVALIDPRINCIPALEXCEPTION_HPP_
#include "com/sun/star/auth/InvalidPrincipalException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_UNSUPPORTEDEXCEPTION_HPP_
#include "com/sun/star/auth/UnsupportedException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_XSSOINITIATORCONTEXT_HPP_
#include "com/sun/star/auth/XSSOInitiatorContext.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_INVALIDCREDENTIALEXCEPTION_HPP_
#include "com/sun/star/auth/InvalidCredentialException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_INVALIDARGUMENTEXCEPTION_HPP_
#include "com/sun/star/auth/InvalidArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::auth::XSSOManager >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.auth.XSSOManager" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::auth::XSSOManager::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::auth::XSSOManager > * >(0));
}

#endif // _COM_SUN_STAR_AUTH_XSSOMANAGER_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/auth/XSSOManager.hpp <==
#ifndef _COM_SUN_STAR_AUTH_XSSOMANAGER_HPP_
#define _COM_SUN_STAR_AUTH_XSSOMANAGER_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AUTH_XSSOMANAGER_HDL_
#include "com/sun/star/auth/XSSOManager.hdl"
#endif

#ifndef _COM_SUN_STAR_AUTH_XSSOACCEPTORCONTEXT_HPP_
#include "com/sun/star/auth/XSSOAcceptorContext.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_INVALIDPRINCIPALEXCEPTION_HPP_
#include "com/sun/star/auth/InvalidPrincipalException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_UNSUPPORTEDEXCEPTION_HPP_
#include "com/sun/star/auth/UnsupportedException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_XSSOINITIATORCONTEXT_HPP_
#include "com/sun/star/auth/XSSOInitiatorContext.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_INVALIDCREDENTIALEXCEPTION_HPP_
#include "com/sun/star/auth/InvalidCredentialException.hpp"
#endif
#ifndef _COM_SUN_STAR_AUTH_INVALIDARGUMENTEXCEPTION_HPP_
#include "com/sun/star/auth/InvalidArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace auth {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::auth::XSSOManager const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.auth.XSSOManager" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::auth::XSSOManager > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::auth::XSSOManager > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::auth::XSSOManager::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::auth::XSSOManager > * >(0));
}

#endif // _COM_SUN_STAR_AUTH_XSSOMANAGER_HPP_
